@@ -12,15 +12,15 @@ __PACKAGE__->mk_classdata( '_mobius_a_column' => 'mobius_a' );
 __PACKAGE__->mk_classdata( '_mobius_b_column' => 'mobius_b' );
 __PACKAGE__->mk_classdata( '_mobius_c_column' => 'mobius_c' );
 __PACKAGE__->mk_classdata( '_mobius_d_column' => 'mobius_d' );
-__PACKAGE__->mk_classdata( '_left_column' => 'left' );
-__PACKAGE__->mk_classdata( '_right_column' => 'right' );
-__PACKAGE__->mk_classdata( '_is_inner_column' => 'inner' );
+__PACKAGE__->mk_classdata( '_lft_column' => 'lft' );
+__PACKAGE__->mk_classdata( '_rgt_column' => 'rgt' );
+__PACKAGE__->mk_classdata( '_is_inner_column' => 'is_inner' );
 
 sub add_mobius_tree_columns {
     my $class = shift;
     my %column_names = @_;
 
-    foreach my $name (qw/ mobius_a mobius_b mobius_c mobius_d left right is_inner /) {
+    foreach my $name (qw/ mobius_a mobius_b mobius_c mobius_d lft rgt is_inner /) {
         next unless exists $column_names{$name};
         my $accessor = "_${name}_column";
         $class->$accessor( $column_names{$name} );
@@ -31,8 +31,8 @@ sub add_mobius_tree_columns {
         $class->_mobius_b_column => { data_type => 'INT', size => 11, is_nullable => 1, extra => { unsigned => 1} },
         $class->_mobius_c_column => { data_type => 'INT', size => 11, is_nullable => 1, extra => { unsigned => 1} },
         $class->_mobius_d_column => { data_type => 'INT', size => 11, is_nullable => 1, extra => { unsigned => 1} },
-        $class->_left_column => { data_type => 'FLOAT', is_nullable => 0, default_value => 1, extra => { unsigned => 1} },
-        $class->_right_column => { data_type => 'FLOAT', is_nullable => 1, default_value => undef, extra => { unsigned => 1} },
+        $class->_lft_column => { data_type => 'DOUBLE', is_nullable => 0, default_value => 1, extra => { unsigned => 1} },
+        $class->_rgt_column => { data_type => 'DOUBLE', is_nullable => 1, default_value => undef, extra => { unsigned => 1} },
         $class->_is_inner_column => { data_type => "BOOLEAN", default_value => 0, is_nullable => 0 },
         );
 
@@ -110,6 +110,7 @@ sub _left_right {
     my ($a, $b, $c, $d) = @_;
     my ($x, $y) = (($a+$b)/($c+$d), $a / $c);
     my ($left, $right) = $x > $y ? ($y, $x) : ($x, $y);
+    warn("DBIx::Class::Tree::Mobius max depth has been reached.") if ($left == $right);
     return wantarray ? ($left, $right) : sprintf("l=%.3f, r=%.3f", $left, $right);
 }
 
@@ -159,8 +160,8 @@ sub insert {
         $self->store_column( $self->_mobius_b_column => $b );
         $self->store_column( $self->_mobius_c_column => $c );
         $self->store_column( $self->_mobius_d_column => $d );
-        $self->store_column( $self->_left_column => $left );
-        $self->store_column( $self->_right_column => $right );
+        $self->store_column( $self->_lft_column => $left );
+        $self->store_column( $self->_rgt_column => $right );
 
         my $r = $self->next::method(@_);
         $parent->update({ $self->_is_inner_column => 1 } );
@@ -175,8 +176,8 @@ sub insert {
         # normal value are b => 1 and c => 0 but it cannot work for SQL join
         $self->store_column( $self->_mobius_b_column => undef );
         $self->store_column( $self->_mobius_d_column => undef );
-        $self->store_column( $self->_left_column => $x );
-        $self->store_column( $self->_right_column => $x + 1 );
+        $self->store_column( $self->_lft_column => $x );
+        $self->store_column( $self->_rgt_column => $x + 1 );
         return $self->next::method(@_);
 
     }
@@ -193,6 +194,12 @@ sub mobius_path {
     return wantarray ? @path : join('.', @path);
 }
 
+sub depth {
+    my $self = shift;
+    my @path = $self->mobius_path();
+    return scalar @path;
+}
+
 sub child_encoding {
     my $self = shift;
     my $x = shift;
@@ -209,8 +216,8 @@ sub child_encoding {
 sub root {
     my $self = shift;
     return $self->result_source->resultset->search( { $self->root_cond } )->search({
-        $self->result_source->resultset->current_source_alias.'.'.$self->_left_column => { '<' => $self->get_column($self->_right_column) },
-        $self->result_source->resultset->current_source_alias.'.'.$self->_right_column => { '>' => $self->get_column($self->_left_column) },
+        $self->result_source->resultset->current_source_alias.'.'.$self->_lft_column => { '<' => $self->get_column($self->_rgt_column) },
+        $self->result_source->resultset->current_source_alias.'.'.$self->_rgt_column => { '>' => $self->get_column($self->_lft_column) },
     });
 }
 
@@ -269,8 +276,8 @@ sub descendants {
     my $self = shift;
 
     return $self->result_source->resultset->search({
-        $self->result_source->resultset->current_source_alias.'.'.$self->_left_column => { '>' => $self->get_column($self->_left_column) },
-        $self->result_source->resultset->current_source_alias.'.'.$self->_right_column => { '<' => $self->get_column($self->_right_column) },
+        $self->result_source->resultset->current_source_alias.'.'.$self->_lft_column => { '>' => $self->get_column($self->_lft_column) },
+        $self->result_source->resultset->current_source_alias.'.'.$self->_rgt_column => { '<' => $self->get_column($self->_rgt_column) },
     });
 }
 
@@ -290,14 +297,14 @@ sub ancestors {
         
     return $self->result_source->resultset->search({
         -and => {
-            $self->result_source->resultset->current_source_alias.'.'.$self->_left_column => { '<' => $self->get_column($self->_left_column) },
-            $self->result_source->resultset->current_source_alias.'.'.$self->_right_column => { '>' => $self->get_column($self->_right_column) },
+            $self->result_source->resultset->current_source_alias.'.'.$self->_lft_column => { '<' => $self->get_column($self->_lft_column) },
+            $self->result_source->resultset->current_source_alias.'.'.$self->_rgt_column => { '>' => $self->get_column($self->_rgt_column) },
         },
-        $self->result_source->resultset->current_source_alias.'.'.$self->_left_column => { '<' => $self->get_column($self->_right_column) },
-        $self->result_source->resultset->current_source_alias.'.'.$self->_right_column => { '>' => $self->get_column($self->_left_column) },
+        $self->result_source->resultset->current_source_alias.'.'.$self->_lft_column => { '<' => $self->get_column($self->_rgt_column) },
+        $self->result_source->resultset->current_source_alias.'.'.$self->_rgt_column => { '>' => $self->get_column($self->_lft_column) },
         $self->result_source->resultset->current_source_alias.'.'.$self->_mobius_a_column => { '!=' => $self->get_column($self->_mobius_a_column) },
         $self->result_source->resultset->current_source_alias.'.'.$self->_mobius_c_column => { '!=' => $self->get_column($self->_mobius_c_column) },
-    },{ order_by => $self->_left_column.' DESC' });
+    },{ order_by => $self->_lft_column.' DESC' });
 }
 
 sub ascendants { return shift(@_)->ancestors(@_) }
@@ -318,8 +325,8 @@ sub attach_child {
         $self->_mobius_b_column => $b,
         $self->_mobius_c_column => $c,
         $self->_mobius_d_column => $d,
-        $self->_left_column => $left,
-        $self->_right_column => $right,
+        $self->_lft_column => $left,
+        $self->_rgt_column => $right,
     });
 
     foreach my $grandchild (@grandchildren) {
@@ -335,7 +342,7 @@ sub attach_child {
 
 Create a table for your tree data with the 7 special columns used by Tree::Mobius.
 By default, these columns are mobius_a mobius_b mobius_b and mobius_d (integer),
-left and right (float) and inner (boolean). See the add_mobius_tree_columns method
+lft and rgt (float) and inner (boolean). See the add_mobius_tree_columns method
 to change the default names.
 
   CREATE TABLE employees (
@@ -344,8 +351,8 @@ to change the default names.
     mobius_b integer(11) unsigned,
     mobius_c integer(11) unsigned,
     mobius_d integer(11) unsigned,
-    left FLOAT unsigned NOT NULL DEFAULT '1',
-    right FLOAT unsigned,
+    lft FLOAT unsigned NOT NULL DEFAULT '1',
+    rgt FLOAT unsigned,
     inner boolean NOT NULL DEFAULT '0',
   );
 
@@ -399,8 +406,12 @@ better tree scaling and directly encode the material path of a node
 using continued fraction (thus this model also relates somewhat with
 the 'Materialized Path' model).
 
-The trade-off of all these advantages over other models is in this
-implementation the use of 7 SQL columns to encode each node.
+The tradeoffs over other models is in this implementation the use of 7
+SQL columns to encode each node.
+
+Since the encoding is not volatile, the depth is constraint by the
+precision of FLOAT in the right and left column. The maximum depth
+reachable is 8 levels with a simple SQL FLOAT, and 21 with a SQL DOUBLE.
 
 This implementation allows you to have several trees in your database.
 
@@ -424,11 +435,12 @@ If the child has descendants, the entire sub-tree is moved recursively.
 
 This method is an override of the DBIx::Class' method.
 
-Typically the method should not be used directly but it allows one to
-add a virtual column to a new row that directly set the parent node
-when calling the DBIx::Class method create.
+The method is not meant to not be used directly but it allows one to
+add a parent virtual column when calling the DBIx::Class method create.
 
-  My::Employee->create({ name => 'Another Intern', parent => $boss });
+This virtual column should be set with the primary key value of the parent.
+
+  My::Employee->create({ name => 'Another Intern', parent => $boss->id });
 
 =head2 parent
 
@@ -496,9 +508,11 @@ Returns the smallest mobius index available in the subtree of a given node.
 
 =head2 child_encoding
 
-Given a mobius index, return the mobius a,b,c,d column values
+Given a mobius index, return the mobius a,b,c,d column values.
 
+=head2 depth
  	
+Return the depth of a node in a tree (depth of a root node is 1).
  	
-=for Pod::Coverage new	mobius_path	root_cond inner_cond leaf_cond
+=for Pod::Coverage new mobius_path root_cond inner_cond leaf_cond
 
